# coding: utf-8

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictBytes, StrictInt, StrictStr, field_validator
from typing import Optional, Union
from typing_extensions import Annotated
from boldsign.models.brand_created import BrandCreated
from boldsign.models.branding_message import BrandingMessage
from boldsign.models.branding_records import BrandingRecords
from boldsign.models.view_brand_details import ViewBrandDetails

from boldsign.api_client import ApiClient, RequestSerialized
from boldsign.api_response import ApiResponse
from boldsign.rest import RESTResponseType
import io


class BrandingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def brand_list(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrandingRecords:
        """List all the brands.


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._brand_list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingRecords",
            '401': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def brand_list_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrandingRecords]:
        """List all the brands.


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._brand_list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingRecords",
            '401': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def brand_list_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List all the brands.


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._brand_list_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingRecords",
            '401': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _brand_list_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/brand/list',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_brand(
        self,
        brand_name: StrictStr,
        brand_logo: Union[StrictBytes, StrictStr],
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrandCreated:
        """Create the brand.


        :param brand_name: (required)
        :type brand_name: str
        :param brand_logo: (required)
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_brand_serialize(
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_brand_with_http_info(
        self,
        brand_name: StrictStr,
        brand_logo: Union[StrictBytes, StrictStr],
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrandCreated]:
        """Create the brand.


        :param brand_name: (required)
        :type brand_name: str
        :param brand_logo: (required)
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_brand_serialize(
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_brand_without_preload_content(
        self,
        brand_name: StrictStr,
        brand_logo: Union[StrictBytes, StrictStr],
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create the brand.


        :param brand_name: (required)
        :type brand_name: str
        :param brand_logo: (required)
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_brand_serialize(
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_brand_serialize(
        self,
        brand_name,
        brand_logo,
        background_color,
        button_color,
        button_text_color,
        email_display_name,
        disclaimer_description,
        disclaimer_title,
        redirect_url,
        is_default,
        can_hide_tag_line,
        combine_audit_trail,
        exclude_audit_trail_from_email,
        email_signed_document,
        document_time_zone,
        show_built_in_form_fields,
        allow_custom_field_creation,
        show_shared_custom_fields,
        hide_decline,
        hide_save,
        document_expiry_settings_expiry_date_type,
        document_expiry_settings_expiry_value,
        document_expiry_settings_enable_default_expiry_alert,
        document_expiry_settings_enable_auto_reminder,
        document_expiry_settings_reminder_days,
        document_expiry_settings_reminder_count,
        custom_domain_settings_domain_name,
        custom_domain_settings_from_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if brand_name is not None:
            _form_params.append(('BrandName', brand_name))
        if brand_logo is not None:
            _files['BrandLogo'] = brand_logo
        if background_color is not None:
            _form_params.append(('BackgroundColor', background_color))
        if button_color is not None:
            _form_params.append(('ButtonColor', button_color))
        if button_text_color is not None:
            _form_params.append(('ButtonTextColor', button_text_color))
        if email_display_name is not None:
            _form_params.append(('EmailDisplayName', email_display_name))
        if disclaimer_description is not None:
            _form_params.append(('DisclaimerDescription', disclaimer_description))
        if disclaimer_title is not None:
            _form_params.append(('DisclaimerTitle', disclaimer_title))
        if redirect_url is not None:
            _form_params.append(('RedirectUrl', redirect_url))
        if is_default is not None:
            _form_params.append(('IsDefault', is_default))
        if can_hide_tag_line is not None:
            _form_params.append(('CanHideTagLine', can_hide_tag_line))
        if combine_audit_trail is not None:
            _form_params.append(('CombineAuditTrail', combine_audit_trail))
        if exclude_audit_trail_from_email is not None:
            _form_params.append(('ExcludeAuditTrailFromEmail', exclude_audit_trail_from_email))
        if email_signed_document is not None:
            _form_params.append(('EmailSignedDocument', email_signed_document))
        if document_time_zone is not None:
            _form_params.append(('DocumentTimeZone', document_time_zone))
        if show_built_in_form_fields is not None:
            _form_params.append(('ShowBuiltInFormFields', show_built_in_form_fields))
        if allow_custom_field_creation is not None:
            _form_params.append(('AllowCustomFieldCreation', allow_custom_field_creation))
        if show_shared_custom_fields is not None:
            _form_params.append(('ShowSharedCustomFields', show_shared_custom_fields))
        if hide_decline is not None:
            _form_params.append(('HideDecline', hide_decline))
        if hide_save is not None:
            _form_params.append(('HideSave', hide_save))
        if document_expiry_settings_expiry_date_type is not None:
            _form_params.append(('DocumentExpirySettings.ExpiryDateType', document_expiry_settings_expiry_date_type))
        if document_expiry_settings_expiry_value is not None:
            _form_params.append(('DocumentExpirySettings.ExpiryValue', document_expiry_settings_expiry_value))
        if document_expiry_settings_enable_default_expiry_alert is not None:
            _form_params.append(('DocumentExpirySettings.EnableDefaultExpiryAlert', document_expiry_settings_enable_default_expiry_alert))
        if document_expiry_settings_enable_auto_reminder is not None:
            _form_params.append(('DocumentExpirySettings.EnableAutoReminder', document_expiry_settings_enable_auto_reminder))
        if document_expiry_settings_reminder_days is not None:
            _form_params.append(('DocumentExpirySettings.ReminderDays', document_expiry_settings_reminder_days))
        if document_expiry_settings_reminder_count is not None:
            _form_params.append(('DocumentExpirySettings.ReminderCount', document_expiry_settings_reminder_count))
        if custom_domain_settings_domain_name is not None:
            _form_params.append(('CustomDomainSettings.DomainName', custom_domain_settings_domain_name))
        if custom_domain_settings_from_name is not None:
            _form_params.append(('CustomDomainSettings.FromName', custom_domain_settings_from_name))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json;odata.metadata=minimal;odata.streaming=true', 
                    'application/json;odata.metadata=minimal;odata.streaming=false', 
                    'application/json;odata.metadata=minimal', 
                    'application/json;odata.metadata=full;odata.streaming=true', 
                    'application/json;odata.metadata=full;odata.streaming=false', 
                    'application/json;odata.metadata=full', 
                    'application/json;odata.metadata=none;odata.streaming=true', 
                    'application/json;odata.metadata=none;odata.streaming=false', 
                    'application/json;odata.metadata=none', 
                    'application/json;odata.streaming=true', 
                    'application/json;odata.streaming=false', 
                    'application/json', 
                    'application/xml', 
                    'application/prs.odatatestxx-odata', 
                    'text/plain', 
                    'text/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/brand/create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_brand(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrandingMessage:
        """Delete the brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_brand_with_http_info(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrandingMessage]:
        """Delete the brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_brand_without_preload_content(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete the brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_brand_serialize(
        self,
        brand_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if brand_id is not None:
            
            _query_params.append(('brandId', brand_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json;odata.metadata=minimal;odata.streaming=true', 
                    'application/json;odata.metadata=minimal;odata.streaming=false', 
                    'application/json;odata.metadata=minimal', 
                    'application/json;odata.metadata=full;odata.streaming=true', 
                    'application/json;odata.metadata=full;odata.streaming=false', 
                    'application/json;odata.metadata=full', 
                    'application/json;odata.metadata=none;odata.streaming=true', 
                    'application/json;odata.metadata=none;odata.streaming=false', 
                    'application/json;odata.metadata=none', 
                    'application/json;odata.streaming=true', 
                    'application/json;odata.streaming=false', 
                    'application/json', 
                    'application/xml', 
                    'application/prs.odatatestxx-odata', 
                    'text/plain', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/brand/delete',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def edit_brand(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        brand_name: Optional[StrictStr] = None,
        brand_logo: Optional[Union[StrictBytes, StrictStr]] = None,
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrandCreated:
        """Edit the brand.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param brand_name:
        :type brand_name: str
        :param brand_logo:
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._edit_brand_serialize(
            brand_id=brand_id,
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def edit_brand_with_http_info(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        brand_name: Optional[StrictStr] = None,
        brand_logo: Optional[Union[StrictBytes, StrictStr]] = None,
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrandCreated]:
        """Edit the brand.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param brand_name:
        :type brand_name: str
        :param brand_logo:
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._edit_brand_serialize(
            brand_id=brand_id,
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def edit_brand_without_preload_content(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        brand_name: Optional[StrictStr] = None,
        brand_logo: Optional[Union[StrictBytes, StrictStr]] = None,
        background_color: Optional[StrictStr] = None,
        button_color: Optional[StrictStr] = None,
        button_text_color: Optional[StrictStr] = None,
        email_display_name: Optional[StrictStr] = None,
        disclaimer_description: Optional[StrictStr] = None,
        disclaimer_title: Optional[StrictStr] = None,
        redirect_url: Optional[StrictStr] = None,
        is_default: Optional[StrictBool] = None,
        can_hide_tag_line: Optional[StrictBool] = None,
        combine_audit_trail: Optional[StrictBool] = None,
        exclude_audit_trail_from_email: Optional[StrictBool] = None,
        email_signed_document: Optional[StrictStr] = None,
        document_time_zone: Optional[StrictStr] = None,
        show_built_in_form_fields: Optional[StrictBool] = None,
        allow_custom_field_creation: Optional[StrictBool] = None,
        show_shared_custom_fields: Optional[StrictBool] = None,
        hide_decline: Optional[StrictBool] = None,
        hide_save: Optional[StrictBool] = None,
        document_expiry_settings_expiry_date_type: Optional[StrictStr] = None,
        document_expiry_settings_expiry_value: Optional[StrictInt] = None,
        document_expiry_settings_enable_default_expiry_alert: Optional[StrictBool] = None,
        document_expiry_settings_enable_auto_reminder: Optional[StrictBool] = None,
        document_expiry_settings_reminder_days: Optional[Annotated[int, Field(le=180, strict=True, ge=1)]] = None,
        document_expiry_settings_reminder_count: Optional[StrictInt] = None,
        custom_domain_settings_domain_name: Optional[StrictStr] = None,
        custom_domain_settings_from_name: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Edit the brand.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param brand_name:
        :type brand_name: str
        :param brand_logo:
        :type brand_logo: io.IOBase
        :param background_color:
        :type background_color: str
        :param button_color:
        :type button_color: str
        :param button_text_color:
        :type button_text_color: str
        :param email_display_name:
        :type email_display_name: str
        :param disclaimer_description:
        :type disclaimer_description: str
        :param disclaimer_title:
        :type disclaimer_title: str
        :param redirect_url:
        :type redirect_url: str
        :param is_default:
        :type is_default: bool
        :param can_hide_tag_line:
        :type can_hide_tag_line: bool
        :param combine_audit_trail:
        :type combine_audit_trail: bool
        :param exclude_audit_trail_from_email:
        :type exclude_audit_trail_from_email: bool
        :param email_signed_document:
        :type email_signed_document: str
        :param document_time_zone:
        :type document_time_zone: str
        :param show_built_in_form_fields:
        :type show_built_in_form_fields: bool
        :param allow_custom_field_creation:
        :type allow_custom_field_creation: bool
        :param show_shared_custom_fields:
        :type show_shared_custom_fields: bool
        :param hide_decline:
        :type hide_decline: bool
        :param hide_save:
        :type hide_save: bool
        :param document_expiry_settings_expiry_date_type:
        :type document_expiry_settings_expiry_date_type: str
        :param document_expiry_settings_expiry_value:
        :type document_expiry_settings_expiry_value: int
        :param document_expiry_settings_enable_default_expiry_alert:
        :type document_expiry_settings_enable_default_expiry_alert: bool
        :param document_expiry_settings_enable_auto_reminder:
        :type document_expiry_settings_enable_auto_reminder: bool
        :param document_expiry_settings_reminder_days:
        :type document_expiry_settings_reminder_days: int
        :param document_expiry_settings_reminder_count:
        :type document_expiry_settings_reminder_count: int
        :param custom_domain_settings_domain_name:
        :type custom_domain_settings_domain_name: str
        :param custom_domain_settings_from_name:
        :type custom_domain_settings_from_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._edit_brand_serialize(
            brand_id=brand_id,
            brand_name=brand_name,
            brand_logo=brand_logo,
            background_color=background_color,
            button_color=button_color,
            button_text_color=button_text_color,
            email_display_name=email_display_name,
            disclaimer_description=disclaimer_description,
            disclaimer_title=disclaimer_title,
            redirect_url=redirect_url,
            is_default=is_default,
            can_hide_tag_line=can_hide_tag_line,
            combine_audit_trail=combine_audit_trail,
            exclude_audit_trail_from_email=exclude_audit_trail_from_email,
            email_signed_document=email_signed_document,
            document_time_zone=document_time_zone,
            show_built_in_form_fields=show_built_in_form_fields,
            allow_custom_field_creation=allow_custom_field_creation,
            show_shared_custom_fields=show_shared_custom_fields,
            hide_decline=hide_decline,
            hide_save=hide_save,
            document_expiry_settings_expiry_date_type=document_expiry_settings_expiry_date_type,
            document_expiry_settings_expiry_value=document_expiry_settings_expiry_value,
            document_expiry_settings_enable_default_expiry_alert=document_expiry_settings_enable_default_expiry_alert,
            document_expiry_settings_enable_auto_reminder=document_expiry_settings_enable_auto_reminder,
            document_expiry_settings_reminder_days=document_expiry_settings_reminder_days,
            document_expiry_settings_reminder_count=document_expiry_settings_reminder_count,
            custom_domain_settings_domain_name=custom_domain_settings_domain_name,
            custom_domain_settings_from_name=custom_domain_settings_from_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandCreated",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _edit_brand_serialize(
        self,
        brand_id,
        brand_name,
        brand_logo,
        background_color,
        button_color,
        button_text_color,
        email_display_name,
        disclaimer_description,
        disclaimer_title,
        redirect_url,
        is_default,
        can_hide_tag_line,
        combine_audit_trail,
        exclude_audit_trail_from_email,
        email_signed_document,
        document_time_zone,
        show_built_in_form_fields,
        allow_custom_field_creation,
        show_shared_custom_fields,
        hide_decline,
        hide_save,
        document_expiry_settings_expiry_date_type,
        document_expiry_settings_expiry_value,
        document_expiry_settings_enable_default_expiry_alert,
        document_expiry_settings_enable_auto_reminder,
        document_expiry_settings_reminder_days,
        document_expiry_settings_reminder_count,
        custom_domain_settings_domain_name,
        custom_domain_settings_from_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if brand_id is not None:
            
            _query_params.append(('brandId', brand_id))
            
        # process the header parameters
        # process the form parameters
        if brand_name is not None:
            _form_params.append(('BrandName', brand_name))
        if brand_logo is not None:
            _files['BrandLogo'] = brand_logo
        if background_color is not None:
            _form_params.append(('BackgroundColor', background_color))
        if button_color is not None:
            _form_params.append(('ButtonColor', button_color))
        if button_text_color is not None:
            _form_params.append(('ButtonTextColor', button_text_color))
        if email_display_name is not None:
            _form_params.append(('EmailDisplayName', email_display_name))
        if disclaimer_description is not None:
            _form_params.append(('DisclaimerDescription', disclaimer_description))
        if disclaimer_title is not None:
            _form_params.append(('DisclaimerTitle', disclaimer_title))
        if redirect_url is not None:
            _form_params.append(('RedirectUrl', redirect_url))
        if is_default is not None:
            _form_params.append(('IsDefault', is_default))
        if can_hide_tag_line is not None:
            _form_params.append(('CanHideTagLine', can_hide_tag_line))
        if combine_audit_trail is not None:
            _form_params.append(('CombineAuditTrail', combine_audit_trail))
        if exclude_audit_trail_from_email is not None:
            _form_params.append(('ExcludeAuditTrailFromEmail', exclude_audit_trail_from_email))
        if email_signed_document is not None:
            _form_params.append(('EmailSignedDocument', email_signed_document))
        if document_time_zone is not None:
            _form_params.append(('DocumentTimeZone', document_time_zone))
        if show_built_in_form_fields is not None:
            _form_params.append(('ShowBuiltInFormFields', show_built_in_form_fields))
        if allow_custom_field_creation is not None:
            _form_params.append(('AllowCustomFieldCreation', allow_custom_field_creation))
        if show_shared_custom_fields is not None:
            _form_params.append(('ShowSharedCustomFields', show_shared_custom_fields))
        if hide_decline is not None:
            _form_params.append(('HideDecline', hide_decline))
        if hide_save is not None:
            _form_params.append(('HideSave', hide_save))
        if document_expiry_settings_expiry_date_type is not None:
            _form_params.append(('DocumentExpirySettings.ExpiryDateType', document_expiry_settings_expiry_date_type))
        if document_expiry_settings_expiry_value is not None:
            _form_params.append(('DocumentExpirySettings.ExpiryValue', document_expiry_settings_expiry_value))
        if document_expiry_settings_enable_default_expiry_alert is not None:
            _form_params.append(('DocumentExpirySettings.EnableDefaultExpiryAlert', document_expiry_settings_enable_default_expiry_alert))
        if document_expiry_settings_enable_auto_reminder is not None:
            _form_params.append(('DocumentExpirySettings.EnableAutoReminder', document_expiry_settings_enable_auto_reminder))
        if document_expiry_settings_reminder_days is not None:
            _form_params.append(('DocumentExpirySettings.ReminderDays', document_expiry_settings_reminder_days))
        if document_expiry_settings_reminder_count is not None:
            _form_params.append(('DocumentExpirySettings.ReminderCount', document_expiry_settings_reminder_count))
        if custom_domain_settings_domain_name is not None:
            _form_params.append(('CustomDomainSettings.DomainName', custom_domain_settings_domain_name))
        if custom_domain_settings_from_name is not None:
            _form_params.append(('CustomDomainSettings.FromName', custom_domain_settings_from_name))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json;odata.metadata=minimal;odata.streaming=true', 
                    'application/json;odata.metadata=minimal;odata.streaming=false', 
                    'application/json;odata.metadata=minimal', 
                    'application/json;odata.metadata=full;odata.streaming=true', 
                    'application/json;odata.metadata=full;odata.streaming=false', 
                    'application/json;odata.metadata=full', 
                    'application/json;odata.metadata=none;odata.streaming=true', 
                    'application/json;odata.metadata=none;odata.streaming=false', 
                    'application/json;odata.metadata=none', 
                    'application/json;odata.streaming=true', 
                    'application/json;odata.streaming=false', 
                    'application/json', 
                    'application/xml', 
                    'application/prs.odatatestxx-odata', 
                    'text/plain', 
                    'text/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/brand/edit',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_brand(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ViewBrandDetails:
        """Get the specific brand details.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ViewBrandDetails",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_brand_with_http_info(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ViewBrandDetails]:
        """Get the specific brand details.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ViewBrandDetails",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_brand_without_preload_content(
        self,
        brand_id: Annotated[StrictStr, Field(description="The brand id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the specific brand details.


        :param brand_id: The brand id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ViewBrandDetails",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_brand_serialize(
        self,
        brand_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if brand_id is not None:
            
            _query_params.append(('brandId', brand_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/brand/get',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reset_default_brand(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BrandingMessage:
        """Reset default brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_default_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def reset_default_brand_with_http_info(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BrandingMessage]:
        """Reset default brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_default_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def reset_default_brand_without_preload_content(
        self,
        brand_id: Annotated[StrictStr, Field(description="brand Id.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Reset default brand.


        :param brand_id: brand Id. (required)
        :type brand_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reset_default_brand_serialize(
            brand_id=brand_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BrandingMessage",
            '401': "ErrorResult",
            '403': "ErrorResult",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reset_default_brand_serialize(
        self,
        brand_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if brand_id is not None:
            
            _query_params.append(('brandId', brand_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json;odata.metadata=minimal;odata.streaming=true', 
                    'application/json;odata.metadata=minimal;odata.streaming=false', 
                    'application/json;odata.metadata=minimal', 
                    'application/json;odata.metadata=full;odata.streaming=true', 
                    'application/json;odata.metadata=full;odata.streaming=false', 
                    'application/json;odata.metadata=full', 
                    'application/json;odata.metadata=none;odata.streaming=true', 
                    'application/json;odata.metadata=none;odata.streaming=false', 
                    'application/json;odata.metadata=none', 
                    'application/json;odata.streaming=true', 
                    'application/json;odata.streaming=false', 
                    'application/json', 
                    'application/xml', 
                    'application/prs.odatatestxx-odata', 
                    'text/plain', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'X-API-KEY', 
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/brand/resetdefault',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from boldsign.api.branding_api import BrandingApi
from boldsign.api.contacts_api import ContactsApi
from boldsign.api.custom_field_api import CustomFieldApi
from boldsign.api.document_api import DocumentApi
from boldsign.api.plan_api import PlanApi
from boldsign.api.sender_identities_api import SenderIdentitiesApi
from boldsign.api.teams_api import TeamsApi
from boldsign.api.template_api import TemplateApi
from boldsign.api.user_api import UserApi

# import ApiClient
from boldsign.api_response import ApiResponse
from boldsign.api_client import ApiClient
from boldsign.configuration import Configuration
from boldsign.exceptions import OpenApiException
from boldsign.exceptions import ApiTypeError
from boldsign.exceptions import ApiValueError
from boldsign.exceptions import ApiKeyError
from boldsign.exceptions import ApiAttributeError
from boldsign.exceptions import ApiException

# import models into sdk package
from boldsign.models.access_code_detail import AccessCodeDetail
from boldsign.models.access_code_details import AccessCodeDetails
from boldsign.models.attachment_info import AttachmentInfo
from boldsign.models.audit_trail import AuditTrail
from boldsign.models.behalf_document import BehalfDocument
from boldsign.models.behalf_document_records import BehalfDocumentRecords
from boldsign.models.behalf_of import BehalfOf
from boldsign.models.billing_view_model import BillingViewModel
from boldsign.models.brand_created import BrandCreated
from boldsign.models.brand_custom_field_details import BrandCustomFieldDetails
from boldsign.models.branding_message import BrandingMessage
from boldsign.models.branding_records import BrandingRecords
from boldsign.models.change_recipient import ChangeRecipient
from boldsign.models.conditional_rule import ConditionalRule
from boldsign.models.contact_created import ContactCreated
from boldsign.models.contact_details import ContactDetails
from boldsign.models.contact_page_details import ContactPageDetails
from boldsign.models.contacts_details import ContactsDetails
from boldsign.models.contacts_list import ContactsList
from boldsign.models.create_contact_response import CreateContactResponse
from boldsign.models.create_sender_identity_request import CreateSenderIdentityRequest
from boldsign.models.create_team_request import CreateTeamRequest
from boldsign.models.create_template_request import CreateTemplateRequest
from boldsign.models.create_user import CreateUser
from boldsign.models.custom_domain_settings import CustomDomainSettings
from boldsign.models.custom_field_collection import CustomFieldCollection
from boldsign.models.custom_field_message import CustomFieldMessage
from boldsign.models.custom_form_field import CustomFormField
from boldsign.models.delete_custom_field_reply import DeleteCustomFieldReply
from boldsign.models.document import Document
from boldsign.models.document_cc import DocumentCC
from boldsign.models.document_cc_details import DocumentCcDetails
from boldsign.models.document_created import DocumentCreated
from boldsign.models.document_expiry_settings import DocumentExpirySettings
from boldsign.models.document_files import DocumentFiles
from boldsign.models.document_form_fields import DocumentFormFields
from boldsign.models.document_info import DocumentInfo
from boldsign.models.document_properties import DocumentProperties
from boldsign.models.document_reassign import DocumentReassign
from boldsign.models.document_records import DocumentRecords
from boldsign.models.document_sender_detail import DocumentSenderDetail
from boldsign.models.document_signer import DocumentSigner
from boldsign.models.document_signer_details import DocumentSignerDetails
from boldsign.models.document_tags import DocumentTags
from boldsign.models.edit_sender_identity_request import EditSenderIdentityRequest
from boldsign.models.edit_template_request import EditTemplateRequest
from boldsign.models.editable_date_field_settings import EditableDateFieldSettings
from boldsign.models.embedded_create_template_request import EmbeddedCreateTemplateRequest
from boldsign.models.embedded_custom_field_created import EmbeddedCustomFieldCreated
from boldsign.models.embedded_document_request import EmbeddedDocumentRequest
from boldsign.models.embedded_send_created import EmbeddedSendCreated
from boldsign.models.embedded_send_template_form_request import EmbeddedSendTemplateFormRequest
from boldsign.models.embedded_signing_link import EmbeddedSigningLink
from boldsign.models.embedded_template_created import EmbeddedTemplateCreated
from boldsign.models.embedded_template_edit_request import EmbeddedTemplateEditRequest
from boldsign.models.embedded_template_edited import EmbeddedTemplateEdited
from boldsign.models.error_result import ErrorResult
from boldsign.models.existing_form_field import ExistingFormField
from boldsign.models.extend_expiry import ExtendExpiry
from boldsign.models.file_info import FileInfo
from boldsign.models.font import Font
from boldsign.models.form_field import FormField
from boldsign.models.form_group import FormGroup
from boldsign.models.id_verification import IdVerification
from boldsign.models.identity_verification_settings import IdentityVerificationSettings
from boldsign.models.image_info import ImageInfo
from boldsign.models.merge_and_send_for_sign_form import MergeAndSendForSignForm
from boldsign.models.notification_settings import NotificationSettings
from boldsign.models.page_details import PageDetails
from boldsign.models.phone_number import PhoneNumber
from boldsign.models.prefill_field import PrefillField
from boldsign.models.prefill_field_request import PrefillFieldRequest
from boldsign.models.problem_details import ProblemDetails
from boldsign.models.recipient_notification_settings import RecipientNotificationSettings
from boldsign.models.rectangle import Rectangle
from boldsign.models.reminder_message import ReminderMessage
from boldsign.models.reminder_settings import ReminderSettings
from boldsign.models.remove_authentication import RemoveAuthentication
from boldsign.models.revoke_document import RevokeDocument
from boldsign.models.role import Role
from boldsign.models.roles import Roles
from boldsign.models.send_for_sign import SendForSign
from boldsign.models.send_for_sign_from_template_form import SendForSignFromTemplateForm
from boldsign.models.sender_identity_list import SenderIdentityList
from boldsign.models.sender_identity_view_model import SenderIdentityViewModel
from boldsign.models.size import Size
from boldsign.models.team_created import TeamCreated
from boldsign.models.team_document_records import TeamDocumentRecords
from boldsign.models.team_list_response import TeamListResponse
from boldsign.models.team_page_details import TeamPageDetails
from boldsign.models.team_response import TeamResponse
from boldsign.models.team_update_request import TeamUpdateRequest
from boldsign.models.team_users import TeamUsers
from boldsign.models.teams import Teams
from boldsign.models.template import Template
from boldsign.models.template_cc import TemplateCC
from boldsign.models.template_created import TemplateCreated
from boldsign.models.template_form_fields import TemplateFormFields
from boldsign.models.template_properties import TemplateProperties
from boldsign.models.template_records import TemplateRecords
from boldsign.models.template_role import TemplateRole
from boldsign.models.template_sender_detail import TemplateSenderDetail
from boldsign.models.template_sender_details import TemplateSenderDetails
from boldsign.models.template_shared_template_detail import TemplateSharedTemplateDetail
from boldsign.models.template_signer_details import TemplateSignerDetails
from boldsign.models.template_tag import TemplateTag
from boldsign.models.text_tag_definition import TextTagDefinition
from boldsign.models.text_tag_offset import TextTagOffset
from boldsign.models.update_user import UpdateUser
from boldsign.models.user_page_details import UserPageDetails
from boldsign.models.user_properties import UserProperties
from boldsign.models.user_records import UserRecords
from boldsign.models.users_details import UsersDetails
from boldsign.models.validation import Validation
from boldsign.models.view_brand_details import ViewBrandDetails
from boldsign.models.view_custom_field_details import ViewCustomFieldDetails



# coding: utf-8

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from boldsign.models.custom_domain_settings import CustomDomainSettings
from boldsign.models.document_expiry_settings import DocumentExpirySettings
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union

class ViewBrandDetails(BaseModel):
    """
    ViewBrandDetails
    """ # noqa: E501
    brand_id: Optional[StrictStr] = Field(default=None, alias="brandId")
    brand_logo: Optional[StrictStr] = Field(default=None, alias="brandLogo")
    brand_name: Optional[StrictStr] = Field(default=None, alias="brandName")
    background_color: Optional[StrictStr] = Field(default=None, alias="backgroundColor")
    button_color: Optional[StrictStr] = Field(default=None, alias="buttonColor")
    button_text_color: Optional[StrictStr] = Field(default=None, alias="buttonTextColor")
    email_display_name: Optional[StrictStr] = Field(default=None, alias="emailDisplayName")
    disclaimer_title: Optional[StrictStr] = Field(default=None, alias="disclaimerTitle")
    disclaimer_description: Optional[StrictStr] = Field(default=None, alias="disclaimerDescription")
    redirect_url: Optional[StrictStr] = Field(default=None, alias="redirectUrl")
    is_default: Optional[StrictBool] = Field(default=None, alias="isDefault")
    can_hide_tag_line: Optional[StrictBool] = Field(default=None, alias="canHideTagLine")
    combine_audit_trail: Optional[StrictBool] = Field(default=None, alias="combineAuditTrail")
    exclude_audit_trail_from_email: Optional[StrictBool] = Field(default=None, alias="excludeAuditTrailFromEmail")
    email_signed_document: Optional[StrictStr] = Field(default=None, alias="emailSignedDocument")
    document_time_zone: Optional[StrictStr] = Field(default=None, alias="documentTimeZone")
    show_built_in_form_fields: Optional[StrictBool] = Field(default=None, alias="showBuiltInFormFields")
    allow_custom_field_creation: Optional[StrictBool] = Field(default=None, alias="allowCustomFieldCreation")
    show_shared_custom_fields: Optional[StrictBool] = Field(default=None, alias="showSharedCustomFields")
    hide_decline: Optional[StrictBool] = Field(default=None, alias="hideDecline")
    hide_save: Optional[StrictBool] = Field(default=None, alias="hideSave")
    document_expiry_settings: Optional[DocumentExpirySettings] = Field(default=None, alias="documentExpirySettings")
    custom_domain_settings: Optional[CustomDomainSettings] = Field(default=None, alias="customDomainSettings")
    is_domain_verified: Optional[StrictBool] = Field(default=None, alias="isDomainVerified")
    __properties: ClassVar[List[str]] = ["brandId", "brandLogo", "brandName", "backgroundColor", "buttonColor", "buttonTextColor", "emailDisplayName", "disclaimerTitle", "disclaimerDescription", "redirectUrl", "isDefault", "canHideTagLine", "combineAuditTrail", "excludeAuditTrailFromEmail", "emailSignedDocument", "documentTimeZone", "showBuiltInFormFields", "allowCustomFieldCreation", "showSharedCustomFields", "hideDecline", "hideSave", "documentExpirySettings", "customDomainSettings", "isDomainVerified"]

    @field_validator('email_signed_document')
    def email_signed_document_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Attachment', 'DocumentLink']):
            raise ValueError("must be one of enum values ('Attachment', 'DocumentLink')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(self, excluded_fields: Set[str] = None) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            elif isinstance(value, list):
                for index, item in enumerate(value):
                    if(isinstance(item, (int, str, bool))):
                        data.append((f'{key}[{index}]', item))
                    else:
                        data.append((key, json.dumps(value[index], ensure_ascii=False)))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ViewBrandDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ViewBrandDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "brandId": obj.get("brandId"),
            "brandLogo": obj.get("brandLogo"),
            "brandName": obj.get("brandName"),
            "backgroundColor": obj.get("backgroundColor"),
            "buttonColor": obj.get("buttonColor"),
            "buttonTextColor": obj.get("buttonTextColor"),
            "emailDisplayName": obj.get("emailDisplayName"),
            "disclaimerTitle": obj.get("disclaimerTitle"),
            "disclaimerDescription": obj.get("disclaimerDescription"),
            "redirectUrl": obj.get("redirectUrl"),
            "isDefault": obj.get("isDefault"),
            "canHideTagLine": obj.get("canHideTagLine"),
            "combineAuditTrail": obj.get("combineAuditTrail"),
            "excludeAuditTrailFromEmail": obj.get("excludeAuditTrailFromEmail"),
            "emailSignedDocument": obj.get("emailSignedDocument"),
            "documentTimeZone": obj.get("documentTimeZone"),
            "showBuiltInFormFields": obj.get("showBuiltInFormFields"),
            "allowCustomFieldCreation": obj.get("allowCustomFieldCreation"),
            "showSharedCustomFields": obj.get("showSharedCustomFields"),
            "hideDecline": obj.get("hideDecline"),
            "hideSave": obj.get("hideSave"),
            "documentExpirySettings": DocumentExpirySettings.from_dict(obj["documentExpirySettings"]) if obj.get("documentExpirySettings") is not None else None,
            "customDomainSettings": CustomDomainSettings.from_dict(obj["customDomainSettings"]) if obj.get("customDomainSettings") is not None else None,
            "isDomainVerified": obj.get("isDomainVerified")
        })
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "brand_id": "(str,)",
            "brand_logo": "(str,)",
            "brand_name": "(str,)",
            "background_color": "(str,)",
            "button_color": "(str,)",
            "button_text_color": "(str,)",
            "email_display_name": "(str,)",
            "disclaimer_title": "(str,)",
            "disclaimer_description": "(str,)",
            "redirect_url": "(str,)",
            "is_default": "(bool,)",
            "can_hide_tag_line": "(bool,)",
            "combine_audit_trail": "(bool,)",
            "exclude_audit_trail_from_email": "(bool,)",
            "email_signed_document": "(str,)",
            "document_time_zone": "(str,)",
            "show_built_in_form_fields": "(bool,)",
            "allow_custom_field_creation": "(bool,)",
            "show_shared_custom_fields": "(bool,)",
            "hide_decline": "(bool,)",
            "hide_save": "(bool,)",
            "document_expiry_settings": "(DocumentExpirySettings,)",
            "custom_domain_settings": "(CustomDomainSettings,)",
            "is_domain_verified": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
        ]




# coding: utf-8

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from boldsign.models.attachment_info import AttachmentInfo
from boldsign.models.conditional_rule import ConditionalRule
from boldsign.models.editable_date_field_settings import EditableDateFieldSettings
from boldsign.models.image_info import ImageInfo
from boldsign.models.rectangle import Rectangle
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union

class FormField(BaseModel):
    """
    FormField
    """ # noqa: E501
    field_type: StrictStr = Field(alias="fieldType")
    page_number: StrictInt = Field(alias="pageNumber")
    bounds: Rectangle
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    is_required: Optional[StrictBool] = Field(default=None, alias="isRequired")
    is_read_only: Optional[StrictBool] = Field(default=None, alias="isReadOnly")
    value: Optional[StrictStr] = None
    font_size: Optional[Union[Annotated[float, Field(strict=True, ge=0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, alias="fontSize")
    font: Optional[StrictStr] = None
    font_hex_color: Optional[StrictStr] = Field(default=None, alias="fontHexColor")
    is_bold_font: Optional[StrictBool] = Field(default=None, alias="isBoldFont")
    is_italic_font: Optional[StrictBool] = Field(default=None, alias="isItalicFont")
    is_under_line_font: Optional[StrictBool] = Field(default=None, alias="isUnderLineFont")
    line_height: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=0)]] = Field(default=None, alias="lineHeight")
    character_limit: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=0)]] = Field(default=None, alias="characterLimit")
    group_name: Optional[StrictStr] = Field(default=None, alias="groupName")
    label: Optional[StrictStr] = None
    place_holder: Optional[StrictStr] = Field(default=None, alias="placeHolder")
    validation_type: Optional[StrictStr] = Field(default=None, alias="validationType")
    validation_custom_regex: Optional[StrictStr] = Field(default=None, alias="validationCustomRegex")
    validation_custom_regex_message: Optional[StrictStr] = Field(default=None, alias="validationCustomRegexMessage")
    date_format: Optional[StrictStr] = Field(default=None, alias="dateFormat")
    time_format: Optional[StrictStr] = Field(default=None, alias="timeFormat")
    image_info: Optional[ImageInfo] = Field(default=None, alias="imageInfo")
    attachment_info: Optional[AttachmentInfo] = Field(default=None, alias="attachmentInfo")
    editable_date_field_settings: Optional[EditableDateFieldSettings] = Field(default=None, alias="editableDateFieldSettings")
    hyperlink_text: Optional[StrictStr] = Field(default=None, alias="hyperlinkText")
    conditional_rules: Optional[List[ConditionalRule]] = Field(default=None, alias="conditionalRules")
    data_sync_tag: Optional[StrictStr] = Field(default=None, alias="dataSyncTag")
    dropdown_options: Optional[List[StrictStr]] = Field(default=None, alias="dropdownOptions")
    text_align: Optional[StrictStr] = Field(default=None, alias="textAlign")
    text_direction: Optional[StrictStr] = Field(default=None, alias="textDirection")
    character_spacing: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="characterSpacing")
    background_hex_color: Optional[StrictStr] = Field(default=None, alias="backgroundHexColor")
    tab_index: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=-1)]] = Field(default=None, alias="tabIndex")
    __properties: ClassVar[List[str]] = ["fieldType", "pageNumber", "bounds", "id", "name", "isRequired", "isReadOnly", "value", "fontSize", "font", "fontHexColor", "isBoldFont", "isItalicFont", "isUnderLineFont", "lineHeight", "characterLimit", "groupName", "label", "placeHolder", "validationType", "validationCustomRegex", "validationCustomRegexMessage", "dateFormat", "timeFormat", "imageInfo", "attachmentInfo", "editableDateFieldSettings", "hyperlinkText", "conditionalRules", "dataSyncTag", "dropdownOptions", "textAlign", "textDirection", "characterSpacing", "backgroundHexColor", "tabIndex"]

    @field_validator('field_type')
    def field_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Signature', 'Initial', 'CheckBox', 'TextBox', 'Label', 'DateSigned', 'RadioButton', 'Image', 'Attachment', 'EditableDate', 'Hyperlink', 'Dropdown', 'Title', 'Company']):
            raise ValueError("must be one of enum values ('Signature', 'Initial', 'CheckBox', 'TextBox', 'Label', 'DateSigned', 'RadioButton', 'Image', 'Attachment', 'EditableDate', 'Hyperlink', 'Dropdown', 'Title', 'Company')")
        return value

    @field_validator('font')
    def font_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Helvetica', 'Courier', 'TimesRoman', 'NotoSans']):
            raise ValueError("must be one of enum values ('Helvetica', 'Courier', 'TimesRoman', 'NotoSans')")
        return value

    @field_validator('validation_type')
    def validation_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['None', 'NumbersOnly', 'EmailAddress', 'Currency', 'CustomRegex']):
            raise ValueError("must be one of enum values ('None', 'NumbersOnly', 'EmailAddress', 'Currency', 'CustomRegex')")
        return value

    @field_validator('text_align')
    def text_align_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Left', 'Center', 'Right']):
            raise ValueError("must be one of enum values ('Left', 'Center', 'Right')")
        return value

    @field_validator('text_direction')
    def text_direction_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['LTR', 'RTL']):
            raise ValueError("must be one of enum values ('LTR', 'RTL')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(self, excluded_fields: Set[str] = None) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            elif isinstance(value, list):
                for index, item in enumerate(value):
                    if(isinstance(item, (int, str, bool))):
                        data.append((f'{key}[{index}]', item))
                    else:
                        data.append((key, json.dumps(value[index], ensure_ascii=False)))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FormField from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FormField from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "fieldType": obj.get("fieldType"),
            "pageNumber": obj.get("pageNumber"),
            "bounds": Rectangle.from_dict(obj["bounds"]) if obj.get("bounds") is not None else None,
            "id": obj.get("id"),
            "name": obj.get("name"),
            "isRequired": obj.get("isRequired"),
            "isReadOnly": obj.get("isReadOnly"),
            "value": obj.get("value"),
            "fontSize": obj.get("fontSize"),
            "font": obj.get("font"),
            "fontHexColor": obj.get("fontHexColor"),
            "isBoldFont": obj.get("isBoldFont"),
            "isItalicFont": obj.get("isItalicFont"),
            "isUnderLineFont": obj.get("isUnderLineFont"),
            "lineHeight": obj.get("lineHeight"),
            "characterLimit": obj.get("characterLimit"),
            "groupName": obj.get("groupName"),
            "label": obj.get("label"),
            "placeHolder": obj.get("placeHolder"),
            "validationType": obj.get("validationType"),
            "validationCustomRegex": obj.get("validationCustomRegex"),
            "validationCustomRegexMessage": obj.get("validationCustomRegexMessage"),
            "dateFormat": obj.get("dateFormat"),
            "timeFormat": obj.get("timeFormat"),
            "imageInfo": ImageInfo.from_dict(obj["imageInfo"]) if obj.get("imageInfo") is not None else None,
            "attachmentInfo": AttachmentInfo.from_dict(obj["attachmentInfo"]) if obj.get("attachmentInfo") is not None else None,
            "editableDateFieldSettings": EditableDateFieldSettings.from_dict(obj["editableDateFieldSettings"]) if obj.get("editableDateFieldSettings") is not None else None,
            "hyperlinkText": obj.get("hyperlinkText"),
            "conditionalRules": [ConditionalRule.from_dict(_item) for _item in obj["conditionalRules"]] if obj.get("conditionalRules") is not None else None,
            "dataSyncTag": obj.get("dataSyncTag"),
            "dropdownOptions": obj.get("dropdownOptions"),
            "textAlign": obj.get("textAlign"),
            "textDirection": obj.get("textDirection"),
            "characterSpacing": obj.get("characterSpacing"),
            "backgroundHexColor": obj.get("backgroundHexColor"),
            "tabIndex": obj.get("tabIndex")
        })
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "field_type": "(str,)",
            "page_number": "(int,)",
            "bounds": "(Rectangle,)",
            "id": "(str,)",
            "name": "(str,)",
            "is_required": "(bool,)",
            "is_read_only": "(bool,)",
            "value": "(str,)",
            "font_size": "(float,)",
            "font": "(str,)",
            "font_hex_color": "(str,)",
            "is_bold_font": "(bool,)",
            "is_italic_font": "(bool,)",
            "is_under_line_font": "(bool,)",
            "line_height": "(int,)",
            "character_limit": "(int,)",
            "group_name": "(str,)",
            "label": "(str,)",
            "place_holder": "(str,)",
            "validation_type": "(str,)",
            "validation_custom_regex": "(str,)",
            "validation_custom_regex_message": "(str,)",
            "date_format": "(str,)",
            "time_format": "(str,)",
            "image_info": "(ImageInfo,)",
            "attachment_info": "(AttachmentInfo,)",
            "editable_date_field_settings": "(EditableDateFieldSettings,)",
            "hyperlink_text": "(str,)",
            "conditional_rules": "(List[ConditionalRule],)",
            "data_sync_tag": "(str,)",
            "dropdown_options": "(List[str],)",
            "text_align": "(str,)",
            "text_direction": "(str,)",
            "character_spacing": "(float,)",
            "background_hex_color": "(str,)",
            "tab_index": "(int,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "conditional_rules",
            "dropdown_options",
        ]




# coding: utf-8

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from boldsign.models.audit_trail import AuditTrail
from boldsign.models.behalf_of import BehalfOf
from boldsign.models.document_cc_details import DocumentCcDetails
from boldsign.models.document_files import DocumentFiles
from boldsign.models.document_form_fields import DocumentFormFields
from boldsign.models.document_reassign import DocumentReassign
from boldsign.models.document_sender_detail import DocumentSenderDetail
from boldsign.models.document_signer_details import DocumentSignerDetails
from boldsign.models.form_group import FormGroup
from boldsign.models.reminder_settings import ReminderSettings
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union

class DocumentProperties(BaseModel):
    """
    DocumentProperties
    """ # noqa: E501
    document_id: Optional[StrictStr] = Field(default=None, alias="documentId")
    brand_id: Optional[StrictStr] = Field(default=None, alias="brandId")
    message_title: Optional[StrictStr] = Field(default=None, alias="messageTitle")
    document_description: Optional[StrictStr] = Field(default=None, alias="documentDescription")
    status: Optional[StrictStr] = None
    files: Optional[List[DocumentFiles]] = None
    sender_detail: Optional[DocumentSenderDetail] = Field(default=None, alias="senderDetail")
    signer_details: Optional[List[DocumentSignerDetails]] = Field(default=None, alias="signerDetails")
    form_groups: Optional[List[FormGroup]] = Field(default=None, alias="formGroups")
    common_fields: Optional[List[DocumentFormFields]] = Field(default=None, alias="commonFields")
    behalf_of: Optional[BehalfOf] = Field(default=None, alias="behalfOf")
    cc_details: Optional[List[DocumentCcDetails]] = Field(default=None, alias="ccDetails")
    reminder_settings: Optional[ReminderSettings] = Field(default=None, alias="reminderSettings")
    reassign: Optional[List[DocumentReassign]] = None
    document_history: Optional[List[AuditTrail]] = Field(default=None, alias="documentHistory")
    activity_by: Optional[StrictStr] = Field(default=None, alias="activityBy")
    activity_date: Optional[StrictInt] = Field(default=None, alias="activityDate")
    activity_action: Optional[StrictStr] = Field(default=None, alias="activityAction")
    created_date: Optional[StrictInt] = Field(default=None, alias="createdDate")
    expiry_days: Optional[StrictInt] = Field(default=None, alias="expiryDays")
    expiry_date: Optional[StrictInt] = Field(default=None, alias="expiryDate")
    enable_signing_order: Optional[StrictBool] = Field(default=None, alias="enableSigningOrder")
    is_deleted: Optional[StrictBool] = Field(default=None, alias="isDeleted")
    revoke_message: Optional[StrictStr] = Field(default=None, alias="revokeMessage")
    decline_message: Optional[StrictStr] = Field(default=None, alias="declineMessage")
    application_id: Optional[StrictStr] = Field(default=None, alias="applicationId")
    labels: Optional[List[StrictStr]] = None
    disable_emails: Optional[StrictBool] = Field(default=None, alias="disableEmails")
    enable_print_and_sign: Optional[StrictBool] = Field(default=None, alias="enablePrintAndSign")
    enable_reassign: Optional[StrictBool] = Field(default=None, alias="enableReassign")
    disable_expiry_alert: Optional[StrictBool] = Field(default=None, alias="disableExpiryAlert")
    hide_document_id: Optional[StrictBool] = Field(default=None, alias="hideDocumentId")
    expiry_date_type: Optional[StrictStr] = Field(default=None, alias="expiryDateType")
    expiry_value: Optional[StrictInt] = Field(default=None, alias="expiryValue")
    document_download_option: Optional[StrictStr] = Field(default=None, alias="documentDownloadOption")
    meta_data: Optional[Dict[str, Optional[StrictStr]]] = Field(default=None, alias="metaData")
    enable_audit_trail_localization: Optional[StrictBool] = Field(default=None, alias="enableAuditTrailLocalization")
    __properties: ClassVar[List[str]] = ["documentId", "brandId", "messageTitle", "documentDescription", "status", "files", "senderDetail", "signerDetails", "formGroups", "commonFields", "behalfOf", "ccDetails", "reminderSettings", "reassign", "documentHistory", "activityBy", "activityDate", "activityAction", "createdDate", "expiryDays", "expiryDate", "enableSigningOrder", "isDeleted", "revokeMessage", "declineMessage", "applicationId", "labels", "disableEmails", "enablePrintAndSign", "enableReassign", "disableExpiryAlert", "hideDocumentId", "expiryDateType", "expiryValue", "documentDownloadOption", "metaData", "enableAuditTrailLocalization"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['InProgress', 'Completed', 'Declined', 'Expired', 'Revoked', 'Draft']):
            raise ValueError("must be one of enum values ('InProgress', 'Completed', 'Declined', 'Expired', 'Revoked', 'Draft')")
        return value

    @field_validator('activity_action')
    def activity_action_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Viewed', 'Signed', 'Reassigned', 'Declined', 'Revoked', 'Expired', 'Downloaded', 'DownloadedForPrintSign', 'InitiatePrintAndSign', 'InitiateFormSign', 'CancelPrintAndSign', 'CompletePrintAndSign', 'Reviewed', 'None', 'EditingInitiated', 'EditingCancelled', 'EditingCompleted']):
            raise ValueError("must be one of enum values ('Viewed', 'Signed', 'Reassigned', 'Declined', 'Revoked', 'Expired', 'Downloaded', 'DownloadedForPrintSign', 'InitiatePrintAndSign', 'InitiateFormSign', 'CancelPrintAndSign', 'CompletePrintAndSign', 'Reviewed', 'None', 'EditingInitiated', 'EditingCancelled', 'EditingCompleted')")
        return value

    @field_validator('expiry_date_type')
    def expiry_date_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Days', 'Hours', 'SpecificDateTime']):
            raise ValueError("must be one of enum values ('Days', 'Hours', 'SpecificDateTime')")
        return value

    @field_validator('document_download_option')
    def document_download_option_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Combined', 'Individually']):
            raise ValueError("must be one of enum values ('Combined', 'Individually')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(self, excluded_fields: Set[str] = None) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            elif isinstance(value, list):
                for index, item in enumerate(value):
                    if(isinstance(item, (int, str, bool))):
                        data.append((f'{key}[{index}]', item))
                    else:
                        data.append((key, json.dumps(value[index], ensure_ascii=False)))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DocumentProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DocumentProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "documentId": obj.get("documentId"),
            "brandId": obj.get("brandId"),
            "messageTitle": obj.get("messageTitle"),
            "documentDescription": obj.get("documentDescription"),
            "status": obj.get("status"),
            "files": [DocumentFiles.from_dict(_item) for _item in obj["files"]] if obj.get("files") is not None else None,
            "senderDetail": DocumentSenderDetail.from_dict(obj["senderDetail"]) if obj.get("senderDetail") is not None else None,
            "signerDetails": [DocumentSignerDetails.from_dict(_item) for _item in obj["signerDetails"]] if obj.get("signerDetails") is not None else None,
            "formGroups": [FormGroup.from_dict(_item) for _item in obj["formGroups"]] if obj.get("formGroups") is not None else None,
            "commonFields": [DocumentFormFields.from_dict(_item) for _item in obj["commonFields"]] if obj.get("commonFields") is not None else None,
            "behalfOf": BehalfOf.from_dict(obj["behalfOf"]) if obj.get("behalfOf") is not None else None,
            "ccDetails": [DocumentCcDetails.from_dict(_item) for _item in obj["ccDetails"]] if obj.get("ccDetails") is not None else None,
            "reminderSettings": ReminderSettings.from_dict(obj["reminderSettings"]) if obj.get("reminderSettings") is not None else None,
            "reassign": [DocumentReassign.from_dict(_item) for _item in obj["reassign"]] if obj.get("reassign") is not None else None,
            "documentHistory": [AuditTrail.from_dict(_item) for _item in obj["documentHistory"]] if obj.get("documentHistory") is not None else None,
            "activityBy": obj.get("activityBy"),
            "activityDate": obj.get("activityDate"),
            "activityAction": obj.get("activityAction"),
            "createdDate": obj.get("createdDate"),
            "expiryDays": obj.get("expiryDays"),
            "expiryDate": obj.get("expiryDate"),
            "enableSigningOrder": obj.get("enableSigningOrder"),
            "isDeleted": obj.get("isDeleted"),
            "revokeMessage": obj.get("revokeMessage"),
            "declineMessage": obj.get("declineMessage"),
            "applicationId": obj.get("applicationId"),
            "labels": obj.get("labels"),
            "disableEmails": obj.get("disableEmails"),
            "enablePrintAndSign": obj.get("enablePrintAndSign"),
            "enableReassign": obj.get("enableReassign"),
            "disableExpiryAlert": obj.get("disableExpiryAlert"),
            "hideDocumentId": obj.get("hideDocumentId"),
            "expiryDateType": obj.get("expiryDateType"),
            "expiryValue": obj.get("expiryValue"),
            "documentDownloadOption": obj.get("documentDownloadOption"),
            "metaData": obj.get("metaData"),
            "enableAuditTrailLocalization": obj.get("enableAuditTrailLocalization")
        })
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "document_id": "(str,)",
            "brand_id": "(str,)",
            "message_title": "(str,)",
            "document_description": "(str,)",
            "status": "(str,)",
            "files": "(List[DocumentFiles],)",
            "sender_detail": "(DocumentSenderDetail,)",
            "signer_details": "(List[DocumentSignerDetails],)",
            "form_groups": "(List[FormGroup],)",
            "common_fields": "(List[DocumentFormFields],)",
            "behalf_of": "(BehalfOf,)",
            "cc_details": "(List[DocumentCcDetails],)",
            "reminder_settings": "(ReminderSettings,)",
            "reassign": "(List[DocumentReassign],)",
            "document_history": "(List[AuditTrail],)",
            "activity_by": "(str,)",
            "activity_date": "(int,)",
            "activity_action": "(str,)",
            "created_date": "(int,)",
            "expiry_days": "(int,)",
            "expiry_date": "(int,)",
            "enable_signing_order": "(bool,)",
            "is_deleted": "(bool,)",
            "revoke_message": "(str,)",
            "decline_message": "(str,)",
            "application_id": "(str,)",
            "labels": "(List[str],)",
            "disable_emails": "(bool,)",
            "enable_print_and_sign": "(bool,)",
            "enable_reassign": "(bool,)",
            "disable_expiry_alert": "(bool,)",
            "hide_document_id": "(bool,)",
            "expiry_date_type": "(str,)",
            "expiry_value": "(int,)",
            "document_download_option": "(str,)",
            "meta_data": "(Dict[str, Optional[str]],)",
            "enable_audit_trail_localization": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "files",
            "signer_details",
            "form_groups",
            "common_fields",
            "cc_details",
            "reassign",
            "document_history",
            "labels",
        ]




# coding: utf-8

"""
    BoldSign API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1
    Contact: support@boldsign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union

class AuditTrail(BaseModel):
    """
    AuditTrail
    """ # noqa: E501
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    to_name: Optional[StrictStr] = Field(default=None, alias="toName")
    to_email: Optional[StrictStr] = Field(default=None, alias="toEmail")
    ipaddress: Optional[StrictStr] = None
    action: Optional[StrictStr] = None
    timestamp: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["id", "name", "email", "toName", "toEmail", "ipaddress", "action", "timestamp"]

    @field_validator('action')
    def action_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Sent', 'Viewed', 'Signed', 'Completed', 'Downloaded', 'Reassigned', 'Declined', 'Recalled', 'Created', 'AuthenticationFailed', 'Reminder', 'AccessCodeChanged', 'AccessCodeViewed', 'DownloadedForPrintSign', 'FormCreated', 'EmailOTP', 'AuthenticationRemoved', 'DownloadedAuditTrail', 'Cloned', 'ClonedWithFieldValues', 'Deleted', 'MovedToTrash', 'Restored', 'AutoReminder', 'Resend', 'Reviewed', 'InitiatePrintSign', 'CancelPrintSign', 'CompletePrintSign', 'GeneratedEmbeddedSignLink', 'EmbeddedSigned', 'EmbeddedReviewed', 'ExpiryDateExtended', 'Attachment', 'EditRecipient', 'AuthenticationAdded', 'AutoReminderON', 'AutoReminderOFF', 'SMSOTP', 'PhoneNumberChanged', 'UnlockedSMSOTP', 'SMSAuthenticationAdded', 'SMSAuthenticationRemoved', 'SMSOTPVerified', 'SMSAuthenticationFailed', 'UnlockEmailOTP', 'EmailAuthenticationAdded', 'EmailAuthenticationRemoved', 'EmailOtpVerify', 'EmailAuthenticationFailed', 'SMSOTPResend', 'EmailOTPResend', 'ResumeDocumentSigning', 'EmailOTPAuthenticationAdded', 'EmailOTPAuthenticationRemoved', 'EmailOTPAuthenticationFailed', 'EmailOTPVerified', 'IdentityVerificationInitiated', 'IdentityVerificationRemoved', 'IdentityVerificationCompleted', 'IdentityVerificationFailed', 'DownloadedVerificationData', 'ManualIdentityVerificationCompleted', 'IdentityVerificationReset', 'CreateEmbeddedVerificationLink', 'SensitiveDataDownloaded', 'IdVerificationRemoved', 'IdVerificationAdded', 'ManualIdentityVerificationInitiated', 'GeneratedSigningLink', 'EditingInitiated', 'EditingCancelled', 'EditingCompleted']):
            raise ValueError("must be one of enum values ('Sent', 'Viewed', 'Signed', 'Completed', 'Downloaded', 'Reassigned', 'Declined', 'Recalled', 'Created', 'AuthenticationFailed', 'Reminder', 'AccessCodeChanged', 'AccessCodeViewed', 'DownloadedForPrintSign', 'FormCreated', 'EmailOTP', 'AuthenticationRemoved', 'DownloadedAuditTrail', 'Cloned', 'ClonedWithFieldValues', 'Deleted', 'MovedToTrash', 'Restored', 'AutoReminder', 'Resend', 'Reviewed', 'InitiatePrintSign', 'CancelPrintSign', 'CompletePrintSign', 'GeneratedEmbeddedSignLink', 'EmbeddedSigned', 'EmbeddedReviewed', 'ExpiryDateExtended', 'Attachment', 'EditRecipient', 'AuthenticationAdded', 'AutoReminderON', 'AutoReminderOFF', 'SMSOTP', 'PhoneNumberChanged', 'UnlockedSMSOTP', 'SMSAuthenticationAdded', 'SMSAuthenticationRemoved', 'SMSOTPVerified', 'SMSAuthenticationFailed', 'UnlockEmailOTP', 'EmailAuthenticationAdded', 'EmailAuthenticationRemoved', 'EmailOtpVerify', 'EmailAuthenticationFailed', 'SMSOTPResend', 'EmailOTPResend', 'ResumeDocumentSigning', 'EmailOTPAuthenticationAdded', 'EmailOTPAuthenticationRemoved', 'EmailOTPAuthenticationFailed', 'EmailOTPVerified', 'IdentityVerificationInitiated', 'IdentityVerificationRemoved', 'IdentityVerificationCompleted', 'IdentityVerificationFailed', 'DownloadedVerificationData', 'ManualIdentityVerificationCompleted', 'IdentityVerificationReset', 'CreateEmbeddedVerificationLink', 'SensitiveDataDownloaded', 'IdVerificationRemoved', 'IdVerificationAdded', 'ManualIdentityVerificationInitiated', 'GeneratedSigningLink', 'EditingInitiated', 'EditingCancelled', 'EditingCompleted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(self, excluded_fields: Set[str] = None) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            elif isinstance(value, list):
                for index, item in enumerate(value):
                    if(isinstance(item, (int, str, bool))):
                        data.append((f'{key}[{index}]', item))
                    else:
                        data.append((key, json.dumps(value[index], ensure_ascii=False)))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuditTrail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuditTrail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "email": obj.get("email"),
            "toName": obj.get("toName"),
            "toEmail": obj.get("toEmail"),
            "ipaddress": obj.get("ipaddress"),
            "action": obj.get("action"),
            "timestamp": obj.get("timestamp")
        })
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "id": "(str,)",
            "name": "(str,)",
            "email": "(str,)",
            "to_name": "(str,)",
            "to_email": "(str,)",
            "ipaddress": "(str,)",
            "action": "(str,)",
            "timestamp": "(int,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
        ]

